
import unittest
import re
import os
import importlib

def discover(start_dir='.', pattern=''):
    if pattern == '':
        suite = unittest.defaultTestLoader.discover(start_dir=start_dir)
    elif os.sep in pattern and pattern[-3:] == '.py':
        package = pattern[:-3].replace(os.path.sep, '.')
        module = importlib.import_module(package)
        suite = unittest.defaultTestLoader.loadTestsFromModule(module)
    elif os.sep in pattern:
        suite = unittest.defaultTestLoader.discover(start_dir=pattern)
    elif pattern[-3:] == '.py':
        suite = unittest.defaultTestLoader.discover(start_dir=start_dir, pattern=pattern)
    else:
        suite = unittest.defaultTestLoader.discover(start_dir=start_dir)
        items = [item for item in suite]
        suite = unittest.TestSuite()

        while len(items):
            nextItems = []
            for item in items:
                if hasattr(item, '__iter__'):
                    nextItems += [ nextItem for nextItem in item ]
                else:
                    if re.search(pattern, item.id()) is not None:
                        suite.addTest(item)
            items = nextItems

    return suite




import click
import unittest
import sputr
import config

@click.command()
@click.version_option(version=config.version)
@click.argument('pattern', default='')
def cli(pattern):
    suite = sputr.discover(pattern=pattern)
    unittest.TextTestRunner().run(suite)

if __name__ == '__main__':
    cli()




from setuptools import setup, find_packages
import importlib

version = importlib.import_module('sputr.config').version

setup(
    name='sputr',
    version=version,
    description='Simple Python Unit Test Runner',
    author='Matt Wisniewski',
    author_email='sputr@mattw.us',
    license='MIT',
    url='https://github.com/polishmatt/sputr',
    keywords=['testing'],
    classifiers=[],
    packages=[
        'sputr'
    ],
    install_requires=[
        'click==6.6'
    ],
    entry_points={
        'console_scripts': [
            'sputr = sputr.cli:cli'
        ],
    },
)
